@@ -27,10 +27,10 @@
 #include "../document.h" // needed for sorting groups
 #include "../translators/bibtexhandler.h" // needed for cleaning text
 
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kmdcodec.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kcalendarsystem.h>
 
 #include <tqlayout.h>
@@ -298,7 +298,7 @@ void TellicoXMLExporter::exportEntryXML(TQDomDocument& dom_, TQDomElement& paren
       entryElem.appendChild(fieldElem);
       // Date fields get special treatment
       if(fIt->type() == Data::Field::Date) {
-        fieldElem.setAttribute(TQString::fromLatin1("calendar"), KGlobal::locale()->calendar()->calendarName());
+        fieldElem.setAttribute(TQString::fromLatin1("calendar"), TDEGlobal::locale()->calendar()->calendarName());
         TQStringList s = TQStringList::split('-', fieldValue, true);
         if(s.count() > 0 && !s[0].isEmpty()) {
           TQDomElement e = dom_.createElement(TQString::fromLatin1("year"));
@@ -490,15 +490,15 @@ TQWidget* TellicoXMLExporter::widget(TQWidget* parent_, const char* name_/*=0*/)
   return m_widget;
 }
 
-void TellicoXMLExporter::readOptions(KConfig* config_) {
-  KConfigGroup group(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
+void TellicoXMLExporter::readOptions(TDEConfig* config_) {
+  TDEConfigGroup group(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
   m_includeImages = group.readBoolEntry("Include Images", m_includeImages);
 }
 
-void TellicoXMLExporter::saveOptions(KConfig* config_) {
+void TellicoXMLExporter::saveOptions(TDEConfig* config_) {
   m_includeImages = m_checkIncludeImages->isChecked();
 
-  KConfigGroup group(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
+  TDEConfigGroup group(config_, TQString::fromLatin1("ExportOptions - %1").arg(formatString()));
   group.writeEntry("Include Images", m_includeImages);
 }
 
